Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(200)

Unified Diff: ppapi/c/ppb_input_event.h

Issue 7715021: Add movement information to PPB_MouseInputEvent. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Removed comments for the 1.0 interface. Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ppapi/cpp/input_event.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ppapi/c/ppb_input_event.h
diff --git a/ppapi/c/ppb_input_event.h b/ppapi/c/ppb_input_event.h
index 2ad6741e124668991554ee3f653450aae4732fd3..8036a7e58c8ca88b980346e1291062c30d550c5e 100644
--- a/ppapi/c/ppb_input_event.h
+++ b/ppapi/c/ppb_input_event.h
@@ -21,7 +21,8 @@
#define PPB_INPUT_EVENT_INTERFACE PPB_INPUT_EVENT_INTERFACE_1_0
#define PPB_MOUSE_INPUT_EVENT_INTERFACE_1_0 "PPB_MouseInputEvent;1.0"
-#define PPB_MOUSE_INPUT_EVENT_INTERFACE PPB_MOUSE_INPUT_EVENT_INTERFACE_1_0
+#define PPB_MOUSE_INPUT_EVENT_INTERFACE_1_1 "PPB_MouseInputEvent;1.1"
+#define PPB_MOUSE_INPUT_EVENT_INTERFACE PPB_MOUSE_INPUT_EVENT_INTERFACE_1_1
#define PPB_WHEEL_INPUT_EVENT_INTERFACE_1_0 "PPB_WheelInputEvent;1.0"
#define PPB_WHEEL_INPUT_EVENT_INTERFACE PPB_WHEEL_INPUT_EVENT_INTERFACE_1_0
@@ -410,6 +411,8 @@ struct PPB_MouseInputEvent {
* @param[in] mouse_position A <code>Point</code> containing the x and y
* position of the mouse when the event occurred.
*
+ * @param[in] mouse_movement The change in position of the mouse.
+ *
* @return A <code>PP_Resource</code> containing the new mouse input event.
*/
PP_Resource (*Create)(PP_Instance instance,
@@ -418,7 +421,8 @@ struct PPB_MouseInputEvent {
uint32_t modifiers,
PP_InputEvent_MouseButton mouse_button,
const struct PP_Point* mouse_position,
- int32_t click_count);
+ int32_t click_count,
+ const struct PP_Point* mouse_movement);
/**
* IsMouseInputEvent() determines if a resource is a mouse event.
*
@@ -441,7 +445,9 @@ struct PPB_MouseInputEvent {
*/
PP_InputEvent_MouseButton (*GetButton)(PP_Resource mouse_event);
/**
* GetPosition() returns the pixel location of a mouse input event.
scheib 2011/08/30 17:44:42 spec has been moving, we're deciding to report the
yzshen1 2011/08/30 22:15:55 Done.
*
* @param[in] mouse_event A <code>PP_Resource</code> containing the mouse
* event.
@@ -455,6 +461,29 @@ struct PPB_MouseInputEvent {
* TODO(brettw) figure out exactly what this means.
*/
int32_t (*GetClickCount)(PP_Resource mouse_event);
+ /**
+ * Returns the change in position of the mouse. When the cursor lock is
+ * enabled, although the mouse position doesn't actually change, this function
+ * continues to provide movement information as when the cursor is unlocked.
+ *
+ * @return The change in position of the mouse, relative to the previous
+ * position.
+ */
+ struct PP_Point (*GetMovement)(PP_Resource mouse_event);
+};
+
+struct PPB_MouseInputEvent_1_0 {
+ PP_Resource (*Create)(PP_Instance instance,
+ PP_InputEvent_Type type,
+ PP_TimeTicks time_stamp,
+ uint32_t modifiers,
+ PP_InputEvent_MouseButton mouse_button,
+ const struct PP_Point* mouse_position,
+ int32_t click_count);
+ PP_Bool (*IsMouseInputEvent)(PP_Resource resource);
+ PP_InputEvent_MouseButton (*GetButton)(PP_Resource mouse_event);
+ struct PP_Point (*GetPosition)(PP_Resource mouse_event);
+ int32_t (*GetClickCount)(PP_Resource mouse_event);
};
/**
« no previous file with comments | « no previous file | ppapi/cpp/input_event.h » ('j') | no next file with comments »
@@ -441,7 +445,9 @@ struct PPB_MouseInputEvent {
PP_InputEvent_MouseButton (*GetButton)(PP_Resource mouse_event);
/**
- * GetPosition() returns the pixel location of a mouse input event.
+ * GetPosition() returns the pixel location of a mouse input event. When
+ * the cursor lock is enabled, it returns the center of the associated plugin
+ * instance.
scheib 2011/08/30 17:44:42 spec has been moving, we're deciding to report the
yzshen1 2011/08/30 22:15:55 Done.

Powered by Google App Engine
This is Rietveld 408576698